# Common Methods

'commonmethods' is a python library that contains methods that I use often, and don't want to rewrite for every project.

# Developing 'Common Methods'
To install the tools needed to develop and run tests, run the following in your virtualenv:

```bash
$ pip install -e .[dev]
```